@@ -1,6 +1,7 @@
 use crate::compare::{Comparison, Logic};
 
 /// An entity in a [Sequence] which can be a another [Sequence] [Entity::Child] or a ComparisonType (Value or Variable) [Entity::Comparison],
+#[derive(Debug, PartialEq)]
 pub enum Entity {
     /// Another sequence which is encapsulated by the current sequence
     Child(Sequence, Option<Logic>),
@@ -9,4 +10,7 @@ pub enum Entity {
 }
 
 /// A sequence of [Entity]s which themselfes represent another [Sequence] or a [Comparison].
-pub type Sequence = Vec<Entity>;
+#[derive(Debug, Default, PartialEq)]
+pub struct Sequence {
+    pub items: Vec<Entity>,
+}
